@@ -1,5 +1,4 @@
-
-grepVar <- function(x, service, day = Sys.Date() - 15, complete = FALSE)
+grepVar <- function(x, service, day = Sys.Date() - 1, complete = FALSE)
 {
     timeFrame <- switch(service,
                         nam = 1,
@@ -9,8 +8,10 @@ grepVar <- function(x, service, day = Sys.Date() - 15, complete = FALSE)
     
     serviceURL <- composeURL(var = NULL, day = day, service = service, 
                              run = '00', spatial = NULL, timeFrame = timeFrame)
-    
-    wcsURL <- paste0(gsub('ncss/grid', 'wcs', serviceURL),
+
+    serviceURL <- gsub('ncss', 'wcs', serviceURL)
+    serviceURL <- gsub('/grid', '', serviceURL)
+    wcsURL <- paste0(serviceURL,
                      '?service=WCS&version=1.0.0&request=GetCapabilities')
     xmlFile <- tempfile()
     download.file(wcsURL, xmlFile)
